import { Injector, OnDestroy, OnInit } from '@angular/core';
import { I18nService, RouterService, StorageService } from '@lightweightform/core';
import { Schema } from '@lightweightform/storage';
/**
 * Abstract class that all components which "encapsulate" a storage value should
 * inherit.
 */
export declare abstract class Value implements OnInit, OnDestroy {
    protected injector: Injector;
    protected i18nService: I18nService;
    protected routerService: RouterService;
    protected storageService: StorageService;
    protected parentValueComponent: Value;
    /**
     * Path of the value in the schema. It may be an absolute path or a relative
     * path (in which case the component will append the path to it's parent
     * component's path).
     */
    _path: string;
    /**
     * Whether the component should render in "read-only" mode (this has no effect
     * if this component is within an already "read-only" component).
     */
    _isReadOnly: boolean;
    /**
     * Add an `lf-value` class to all value components.
     */
    _classLfValue: boolean;
    /**
     * Disposer for the path observer.
     */
    private disposePathObserve;
    constructor(injector: Injector, i18nService: I18nService, routerService: RouterService, storageService: StorageService, parentValueComponent: Value);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Label associated with this value.
     */
    readonly label: string | undefined;
    /**
     * Code associated with this value.
     */
    readonly code: string | undefined;
    /**
     * Help message associated with this value.
     */
    readonly helpMessage: string | undefined;
    /**
     * Legend associated with this value.
     */
    readonly legend: string | undefined;
    /**
     * Message used to ask the user to retry validating the value.
     */
    readonly retryValidateText: string;
    /**
     * Absolute path of the value.
     */
    readonly path: string;
    /**
     * Storage relative with its "current path" set to this component's path.
     */
    readonly relativeStorage: StorageService;
    /**
     * Whether the component should render in "read-only" mode. Inherits the
     * "read-only" state of parent components (meaning that it's not possible to
     * have an "editable" component within a "read-only" one). Furthermore, if the
     * component's value is computed, the component will always be in "read-only"
     * mode.
     */
    readonly isReadOnly: boolean;
    /**
     * Obtain the translation for a given key associated to the value's path,
     * possibly providing a default value for when no translation was found.
     * @param key Key of the translation.
     * @param dft Default value for the translation.
     * @returns Translation for the provided key in the current language.
     */
    translate(key: string, dft?: string): any;
    /**
     * Method that all componentes which represent a storage value should
     * implement to validate that the component's path represents a schema that
     * the component knows how to represent.
     * @param schema Schema to validate.
     */
    protected abstract validateSchema(schema: Schema): any;
}
